Method: System::Ruby.platform

Defined in:
lib/system/ruby.rb

.platformString

Return the system platform the current Ruby interpreter is running on.

Examples:

System::Ruby.platform # => "x86_64-darwin12.2.0"

Returns:

  • (String)

    The system platform the current Ruby interpreter is running on.

Since:

  • 0.1.1



# File 'lib/system/ruby.rb', line 110