Return the system platform the current Ruby interpreter is running on.
System::Ruby.platform # => "x86_64-darwin12.2.0"
Returns:
The system platform the current Ruby interpreter is running on.
Since:
0.1.1
# File 'lib/system/ruby.rb', line 110